@@ -14,19 +14,15 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>                      */
 
 // Local Includes
 #include "filters.h"
 #include "filterinfo.h"
 
 // KDE Includes
-#include <QUrl>
-#include <KLocalizedString>
 #include "mailimporter_debug.h"
 
-#include <QScopedPointer>
-
 //////////////////////////////////////////////////////////////////////////////////
 //
 // The generic filter class
@@ -55,8 +51,8 @@ public:
     QString author;
     QString info;
     QString mailDir;
-    MailImporter::FilterImporterBase *filterImporter;
-    MailImporter::FilterInfo *filterInfo;
+    MailImporter::FilterImporterBase *filterImporter = nullptr;
+    MailImporter::FilterInfo *filterInfo = nullptr;
 };
 
 Filter::Filter(const QString &name, const QString &author, const QString &info)
